@@ -1,4 +1,4 @@
-# $Header: /home/fergal/my/cvs/Test-Tester/lib/Test/Tester.pm,v 1.21 2003/03/18 11:16:37 fergal Exp $
+# $Header: /home/fergal/my/cvs/Test-Tester/lib/Test/Tester.pm,v 1.22 2003/03/20 12:05:20 fergal Exp $
 use strict;
 
 package Test::Tester;
@@ -10,7 +10,7 @@ require Exporter;
 
 use vars qw( @ISA @EXPORT $VERSION );
 
-$VERSION = "0.04";
+$VERSION = "0.06";
 @EXPORT = qw( run_tests check_tests check_test cmp_results );
 @ISA = qw( Exporter );
 
@@ -41,7 +41,8 @@ sub check_test
 {
 	my $test = shift;
 	my $expect = shift;
-	my $name = shift || "";
+	my $name = shift;
+	$name = "" unless defined($name);
 
 	my ($prem, @results) = do
 	{
@@ -56,7 +57,8 @@ sub check_tests
 {
 	my $test = shift;
 	my $expects = shift;
-	my $name = shift || "";
+	my $name = shift;
+	$name = "" unless defined($name);
 
 	my ($prem, @results) = eval { run_tests($test, $name) };
 
@@ -84,7 +86,8 @@ sub cmp_result
 {
 	my ($result, $expect, $name) = @_;
 
-	my $sub_name = $result->{name} || "";
+	my $sub_name = $result->{name};
+	$sub_name = "" unless defined($name);
 
 	my $desc = "subtest '$sub_name' of '$name'";
 
